# Talk Gooder

`talkgooder` attempts to smooth out grammar, punctuation, and number-related corner cases when formatting text for human consumption. It is intended for applications where you know there's a noun and are trying to generate text, but you don't know much about it.

It handles:

* Plurals
* Possessives
* Numbers to words
* "There is" vs. "There are"
* "A" vs. "An"

``talkgooder`` is currently specific to American English, but it is extensible to other languages.

Contributions are welcome at [github.com/brianwarner/talkgooder](https://github.com/brianwarner/talkgooder)!
